# Instructions

Pour la recherche suivante :
*{{intention}}*

*La requête SQL correcte* est :
```sql
{{requete_attendue}}
```

L'élève propose *la requête SQL* suivante :
```sql
{{requete}}
```

L'analyse de la table résultat donne :
*{{cmp}}*

Indiquer à l'élève si sa requête est équivalente à la requête correcte.
Si ce n'est pas le cas, lui expliquer les différences et là où il s'est trompé.
Si c'est le cas, le féliciter et expliquer pourquoi sa requête est correcte.
